Structs
Constants
- BIOS_
BOOT - BIOS boot partition type GUID for GPT
- ESP
- EFI System Partition (ESP) for UEFI boot on GPT
- ESP_
ID_ MBR - MBR partition type IDs that indicate an EFI System Partition. 0x06 is FAT16 (used as ESP on some MBR systems), 0xEF is the explicit EFI System Partition type. Refer to https://en.wikipedia.org/wiki/Partition_type
Functions
- is_
dir_ backing_ device_ ro - Determine whether the block device backing the filesystem mounted at the given directory is physically read-only.
- list_
dev - list_
dev_ by_ dir - List the device containing the filesystem mounted at the given directory.
- parse_
size_ mib - Parse a string into mibibytes
- run_
loopback_ cleanup_ helper - Main function for the loopback cleanup helper process This function does not return - it either exits normally or via signal